Blitter

Enum Blitter 

#[non_exhaustive]
pub enum Blitter { Default, Ascii, Half, Quadrant, Sextant, Braille, Pixel, _4x1, _8x1, }
Blitter mode to use for rasterizing a Visual.

We never blit full blocks, but instead spaces (more efficient) with the background set to the desired foreground.

Degradation

There is a mechanism of graceful degradation, that works as follows:

Pixel > Sextant > Quadrant > Half > Ascii.

If you don’t want this behaviour you have to call the degrade method of VisualBuilder (or the set_degrade method of Visual) to false.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Default



Ascii

Blitter mode using only spaces, compatible with ASCII (1x1).



Half

Blitter mode using halves + Ascii (2x1).

▄▀



Quadrant

Blitter mode using quadrants + Half (2x2).

▗▐ ▖▀▟▌▙



Sextant

Blitter mode using sextants + Quadrant (3x2).

🬀🬁🬂🬃🬄🬅🬆🬇🬈🬉🬊🬋🬌🬍🬎🬏🬐🬑🬒🬓🬔🬕🬖🬗🬘🬙🬚🬛🬜🬝🬞🬟🬠🬡🬢🬣🬤🬥🬦🬧🬨🬩🬪🬫🬬🬭🬮🬯🬰🬱🬲🬳🬴🬵🬶🬷🬸🬹🬺🬻



Braille

Blitter mode using braille (4x2).

⡀⡄⡆⡇⢀⣀⣄⣆⣇⢠⣠⣤⣦⣧⢰⣰⣴⣶⣷⢸⣸⣼⣾⣿



Pixel

Blitter mode using Pixels/Sixels.



_4x1

Blitter mode using: four vertical levels (4x1).

█▆▄▂



_8x1

Blitter mode using: eight vertical levels (8x1).

█▇▆▅▄▃▂▁

Implementations

Source

impl Blitter

aliases

pub const _1x1: Blitter = Blitter::Ascii

pub const _2x1: Blitter = Blitter::Half

pub const _2x2: Blitter = Blitter::Quadrant

pub const _3x2: Blitter = Blitter::Sextant

Source

impl Blitter

methods

pub const fn cell_height(&self) -> Option<u8>

The number of height subdivisions in a cell using the current blitter.

Default & Pixel returns None.

pub const fn cell_width(&self) -> Option<u8>

The number of width subdivisions in a cell using the current blitter.

Default & Pixel returns None.

pub const fn cell_size(&self) -> Option<(u8, u8)>

The inner Cell’s dimensions (width, height) using the current blitter.

Default & Pixel returns None.