Channels

Struct Channels 

#[repr(transparent)]
pub struct Channels { pub nc: NcChannels, }
A pair of both foreground and background Channels.

Fields

nc: NcChannels

Implementations

Source

impl Channels

constructors

pub fn new() -> Channels

A new pair of channels, set to black and NOT using the default colors.

pub fn with_default() -> Channels

A new pair of channels set to black and using the default colors.

pub fn from_rgb(fg_rgb: impl Into<Rgb>, bg_rgb: impl Into<Rgb>) -> Channels

A new pair of channels, using separate foreground and background colors.

pub fn from_rgb_both(rgb: impl Into<Rgb>) -> Channels

A new pair of channels, using the same foreground and background colors.

pub fn from_rgb_alpha( fg_rgb: impl Into<Rgb>, fg_alpha: impl Into<Alpha>, bg_rgb: impl Into<Rgb>, bg_alpha: impl Into<Alpha>, ) -> Channels

A new pair of channels, using separate foreground and background colors, and alpha.

pub fn from_rgb_alpha_both( rgb: impl Into<Rgb>, alpha: impl Into<Alpha>, ) -> Channels

A new pair of channels, using the same foreground and background colors.

pub fn combine(fg: impl Into<Channel>, bg: impl Into<Channel>) -> Channels

Combines two separate Channels into Channels.

Source

impl Channels

methods

pub fn fg(&self) -> Channel

Gets the foreground channel.

pub fn bg(&self) -> Channel

Gets the background channel.

pub fn set_fg(&mut self, fg: impl Into<Channel>) -> Channels

Sets the foreground channel.

pub fn set_bg(&mut self, bg: impl Into<Channel>) -> Channels

Sets the background channel.

pub fn channels(&self) -> Channels

Gets the alpha and coloring bits as Channels.

pub fn set_channels(&mut self, other: impl Into<Channels>) -> Channels

Sets the alpha and coloring bits from another Channels.

pub fn reverse(&mut self) -> Self

Returns the Channels with the foreground and background’s color information swapped, but without touching the rest of the bits.

Alpha is retained unless it would lead to an illegal state: HighContrast, Transparent and Blend are taken to Opaque unless the new value is Rgb.