Input

Struct Input 

pub struct Input {
    pub received: Received,
    pub keymod: KeyMod,
    pub itype: InputType,
    pub cell: Option<Position>,
    pub offset: Option<Position>,
}
A received input.

Fields

received: Received

The received input event.

keymod: KeyMod

Keyboard modifiers.

itype: InputType

The type of the input.

cell: Option<Position>

The cell position of the event, if defined.

offset: Option<Position>

Pixel offset within the cell, if defined.

Implementations

Source

impl Input

methods

pub const fn received(&self) -> bool

Returns true if any actual input has been received.

pub const fn some_key(&self) -> bool

Returns true if some Key has been received.

pub fn is_key(&self, key: Key) -> bool

Returns true if a specific Key has been received.

pub const fn some_char(&self) -> bool

Returns true if some character has been received.

pub const fn is_char(&self, character: char) -> bool

Returns true if a specific character has been received.

pub const fn is_press(&self) -> bool

Returns true if this’ a Press input type.

pub const fn is_repeat(&self) -> bool

Returns true if this’ a Repeat input type.

pub const fn is_release(&self) -> bool

Returns true if this’ a Release input type.