Struct notcurses::Style

source ·
pub struct Style(_);
A bitmask of styles.

Implementations

source

impl Style

source

pub const Bold: Self = _

Bold.

source

pub const Italic: Self = _

Italic.

source

pub const Struck: Self = _

Struck.

source

pub const Underline: Self = _

Underline.

source

pub const Undercurl: Self = _

Undercurl.

source

pub const None: Self = _

None of the styles (all bits set to 0).

source

pub const Mask: Self = _

The mask of all styles (all bits set to 1).

source

impl Style

source

pub fn from_names(names: &str) -> Style

Returns a style from a case-insensitive string representation.

The received styles must be separated by spaces.

source

impl Style

source

pub fn to_vec(&self) -> Vec<Style>

Returns a Vec with all the styles contained in the current style.

source

pub fn has(&self, other: impl Into<Style>) -> bool

Returns true if the current style has included the other_style.

source

pub fn set(&mut self, other: impl Into<Style>)

Sets the other style in the current style.

source

pub fn unset(&mut self, other: impl Into<Style>)

Unsets the other style in the current style.