pub unsafe extern "C" fn freopen(
__filename: *const i8,
__modes: *const i8,
__stream: *mut _IO_FILE,
) -> *mut _IO_FILEExpand description
Open a file, replacing an existing stream with it.
This function is a possible cancellation point and therefore not marked with __THROW.