pub unsafe extern "C" fn ncplane_set_base(
n: *mut ncplane,
egc: *const i8,
stylemask: u16,
channels: u64,
) -> i32Expand description
Set the ncplane’s base nccell. It will be used for purposes of rendering anywhere that the ncplane’s gcluster is 0. Note that the base cell is not affected by ncplane_erase(). ‘egc’ must be an extended grapheme cluster. Returns the number of bytes copied out of ‘gcluster’, or -1 on failure.