NcStyle

Struct NcStyle 

#[repr(transparent)]
pub struct NcStyle(pub u16);
A bitmask of styles.

Flags

Default

*NcStyle::None

Notes

Tuple Fields

0: u16

Implementations

Source

impl NcStyle

Flags

pub const Bold: NcStyle

Bold.

pub const Italic: NcStyle

Italic.

pub const Struck: NcStyle

Struck.

pub const Underline: NcStyle

Underline.

pub const Undercurl: NcStyle

Undercurl.

pub const None: NcStyle

None of the styles (all bits set to 0).

pub const Mask: NcStyle

The mask of all styles (all bits set to 1).

Source

impl NcStyle

Methods

pub fn to_vec(&self) -> Vec<NcStyle>

Returns a Vec with all the styles contained in the current style.

pub fn has(&self, other: impl Into<NcStyle>) -> bool

Returns true if the current style has included the other_style.

pub fn set(&mut self, other: impl Into<NcStyle>)

Sets the other style in the current style.

pub fn unset(&mut self, other: impl Into<NcStyle>)

Unsets the other style in the current style.