Struct Channels
Source #[repr(transparent)]
pub struct Channels {
pub nc: NcChannels,
}
A pair of both foreground and background Channels.
A new pair of channels, set to black and NOT using the default colors.
A new pair of channels set to black and using the default colors.
A new pair of channels, using separate foreground and background colors.
A new pair of channels, using the same foreground and background colors.
A new pair of channels, using separate foreground and background colors,
and alpha.
A new pair of channels, using the same foreground and background colors.
Combines two separate Channels into Channels.
Gets the foreground channel.
Gets the background channel.
Sets the foreground channel.
Sets the background channel.
Gets the alpha and coloring bits as Channels.
Sets the alpha and coloring bits from another Channels.
Returns the Channels with the foreground and background’s color information
swapped, but without touching the rest of the bits.
Alpha is retained unless it would lead to an illegal state:
HighContrast, Transparent and Blend are taken to Opaque
unless the new value is Rgb.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Formats the value using the given formatter.
Read more
Converts to this type from the input type.
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [[r, g, b], [r, g, b]]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of [fg, bg] impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background [r, g, b, r, g, b]).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background ((r, g, b), (r, g, b)).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from a pair of (fg, bg) impl Into<Channel>’s.
New Channels from same foreground & background (r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
New Channels from different foreground & background (r, g, b, r, g, b).
Performs a saturating cast to [u8; 3], [u8; 3].
SourceConverts a Channels into a (fg, bg) Channel tuple.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.