pub unsafe extern "C" fn ncmenu_unroll( n: *mut ncmenu, sectionidx: i32, ) -> i32
Unroll the specified menu section, making the menu visible if it was invisible, and rolling up any menu section that is already unrolled.