pub type NcVisual = ncvisual;Expand description
A visual bit of multimedia.
It can be constructed from a rgba or bgra buffer.
The NcVisualOptions structure is used only by the following methods:
Aliased Type
pub struct NcVisual { /* private fields */ }